@@ -1,10 +1,20 @@
 <?php
-require_once 'libs/session_check.php';
+// Check if user is authenticated
+if (!defined('AUTH_USER')) {
+    header('Location: login.php');
+    exit();
+}
+
 require_once 'libs/CpanelBackupImporter.php';
+require_once 'libs/mysqlmgmt.php';
 
 $pageTitle = "cPanel Backup Import";
 $currentPage = 'cpanel-import';
 
+// Initialize database connection
+$MySQLMgmt = new mysqlmgmt();
+$pdo = $MySQLMgmt->getMySQLConnection();
+
 // Handle AJAX requests
 if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
     header('Content-Type: application/json');
@@ -41,7 +51,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
 }
 
 function getAvailableBackupFiles() {
-    $userfilesDir = '/docker/users/' . $_SESSION['username'] . '/userfiles';
+    $userfilesDir = '/docker/users/' . AUTH_USER . '/userfiles';
     $backupFiles = [];
     
     if (is_dir($userfilesDir)) {
@@ -70,7 +80,7 @@ function selectBackupFile() {
     }
     
     $selectedFile = $_POST['backup_file'];
-    $userfilesDir = '/docker/users/' . $_SESSION['username'] . '/userfiles';
+    $userfilesDir = '/docker/users/' . AUTH_USER . '/userfiles';
     $fullPath = $userfilesDir . '/' . basename($selectedFile);
     
     // Validate file exists and is in userfiles directory
@@ -104,12 +114,12 @@ function startImport($backupFilePath) {
         INSERT INTO cpanel_imports (import_id, username, backup_file, status, created_at) 
         VALUES (?, ?, ?, 'running', NOW())
     ");
-    $stmt->execute([$importId, $_SESSION['username'], $backupFilePath]);
+    $stmt->execute([$importId, AUTH_USER, $backupFilePath]);
     
     // Start import in background
     $command = "php " . __DIR__ . "/../scripts/run-cpanel-import.php " . 
                escapeshellarg($importId) . " " . 
-               escapeshellarg($_SESSION['username']) . " " . 
+               escapeshellarg(AUTH_USER) . " " . 
                escapeshellarg($backupFilePath) . " > /dev/null 2>&1 &";
     
     exec($command);
@@ -124,7 +134,7 @@ function getImportStatus($importId) {
     global $pdo;
     
     $stmt = $pdo->prepare("SELECT * FROM cpanel_imports WHERE import_id = ? AND username = ?");
-    $stmt->execute([$importId, $_SESSION['username']]);
+    $stmt->execute([$importId, AUTH_USER]);
     $import = $stmt->fetch(PDO::FETCH_ASSOC);
     
     if (!$import) {
